# coding:utf-8

__project__ = "xpw-locker"
__version__ = "0.7.1"
__urlhome__ = "https://github.com/podboy/locker/"
__description__ = "Access authentication"
__official_name__ = "Locker"

# author
__author__ = "Mingzhe Zou"
__author_email__ = "zoumingzhe@outlook.com"
